from setuptools import setup, find_packages

setup(
    name='minidb-project',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        # Adicione aqui as dependências necessárias
    ],
    description='Uma biblioteca de banco de dados simples que funciona a partir do script',
    long_description=open('README.md').read(),  # Certifique-se de que você tem um README.md
    long_description_content_type='text/markdown',  # Formato do README
    author='Arthur Saert',
    author_email='contato@grupomuller.org.br',
    url='https://grupomuller.org.br',  # URL do repositório
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',  # ou a licença que você escolher
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)


# mini_db.py

class Database:
    def __init__(self):
        self.tables = {}
        self.current_table = None

    def create_table(self, name):
        self.tables[name] = []
        # print(f"Tabela '{name}' criada.")  # Comente ou remova essa linha

    def navigate(self, table_name):
        self.current_table = table_name
        # print(f"Navegando para a tabela '{table_name}'.")  # Comente ou remova essa linha

    def insert(self, record):
        self.tables[self.current_table].append(record)
        # print(f"Registro inserido na tabela '{self.current_table}': {record}")  # Comente ou remova essa linha

    def select(self):
        return self.tables[self.current_table]